# neuralwatermark


[![image](https://img.shields.io/pypi/v/neuralwatermark.svg)](https://pypi.python.org/pypi/neuralwatermark)

[![image](https://img.shields.io/conda/vn/conda-forge/neuralwatermark.svg)](https://anaconda.org/conda-forge/neuralwatermark)

[![image](https://pyup.io/repos/github/skp-github/neuralwatermark/shield.svg)](https://pyup.io/repos/github/skp-github/neuralwatermark)


**Python package to watermark AI models**


-   Free software: GNU General Public License v3
-   Documentation: https://skp-github.github.io/neuralwatermark
    

## Features

-   TODO

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.
